@@ -14,9 +14,10 @@ static GtkWidget *check_button_gtab_dup_select_bell,
                  *check_button_gtab_shift_phrase_key,
                  *check_button_gtab_hide_row2,
                  *check_button_gtab_in_row1,
-                 *check_button_gtab_capslock_in_eng;
-                 *check_button_gtab_vertical_select;
-                 *check_button_gtab_unique_auto_send;
+                 *check_button_gtab_capslock_in_eng,
+                 *check_button_gtab_vertical_select,
+                 *check_button_gtab_unique_auto_send,
+                 *check_button_gcin_capslock_lower;
 
 struct {
   char *str;
@@ -83,6 +84,9 @@ static gboolean cb_gtab_conf_ok( GtkWidget *widget,
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gtab_unique_auto_send)));
 
 
+  save_gcin_conf_int(GCIN_CAPSLOCK_LOWER,
+    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_capslock_lower)));
+
   int idx = gtk_option_menu_get_history (GTK_OPTION_MENU (opt_spc_opts));
   save_gcin_conf_int(GTAB_SPACE_AUTO_FIRST, spc_opts[idx].num);
 
@@ -128,7 +132,7 @@ static gboolean cb_gtab_edit_append( GtkWidget *widget,
 static GtkWidget *create_spc_opts()
 {
   GtkWidget *hbox = gtk_hbox_new (FALSE, 1);
-  GtkWidget *label = gtk_label_new("空白鍵選項");
+  GtkWidget *label = gtk_label_new(_("空白鍵選項"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
   opt_spc_opts = gtk_option_menu_new ();
@@ -168,14 +172,14 @@ void create_gtab_conf_window()
                     G_CALLBACK (close_gtab_conf_window),
                     NULL);
 
-  gtk_window_set_title (GTK_WINDOW (gcin_gtab_conf_window), "倉頡/行列/嘸蝦米/大易設定");
+  gtk_window_set_title (GTK_WINDOW (gcin_gtab_conf_window), _("倉頡/行列/嘸蝦米/大易設定"));
   gtk_container_set_border_width (GTK_CONTAINER (gcin_gtab_conf_window), 3);
 
   GtkWidget *vbox_top = gtk_vbox_new (FALSE, 10);
   gtk_container_add (GTK_CONTAINER (gcin_gtab_conf_window), vbox_top);
 
 
-  GtkWidget *frame_gtab = gtk_frame_new("倉頡/行列/嘸蝦米/大易");
+  GtkWidget *frame_gtab = gtk_frame_new(_("倉頡/行列/嘸蝦米/大易"));
   gtk_container_set_border_width (GTK_CONTAINER (frame_gtab), 5);
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_gtab, FALSE, FALSE, 0);
   GtkWidget *vbox_gtab = gtk_vbox_new (FALSE, 10);
@@ -185,7 +189,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_dup_select_bell = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_dup_select_bell, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_sele = gtk_label_new("重複字選擇鈴聲");
+  GtkWidget *label_gtab_sele = gtk_label_new(_("重複字選擇鈴聲"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_dup_select_bell), label_gtab_sele,  FALSE, FALSE, 0);
   check_button_gtab_dup_select_bell = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_dup_select_bell),check_button_gtab_dup_select_bell,  FALSE, FALSE, 0);
@@ -197,7 +201,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_auto_select_by_phrase = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_auto_select_by_phrase, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_auto_select = gtk_label_new("由詞庫自動選擇字");
+  GtkWidget *label_gtab_auto_select = gtk_label_new(_("由詞庫自動選擇字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_auto_select_by_phrase), label_gtab_auto_select,  FALSE, FALSE, 0);
   check_button_gtab_auto_select_by_phrase = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_auto_select_by_phrase),check_button_gtab_auto_select_by_phrase,  FALSE, FALSE, 0);
@@ -208,7 +212,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_pre_select = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_pre_select, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_pre_select = gtk_label_new("預覽/預選 字");
+  GtkWidget *label_gtab_pre_select = gtk_label_new(_("預覽/預選 字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_pre_select), label_gtab_pre_select,  FALSE, FALSE, 0);
   check_button_gtab_pre_select = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_pre_select),check_button_gtab_pre_select,  FALSE, FALSE, 0);
@@ -219,7 +223,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_press_full_auto_send = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_press_full_auto_send, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_press_full_auto_send = gtk_label_new("按滿自動送字");
+  GtkWidget *label_gtab_gtab_press_full_auto_send = gtk_label_new(_("按滿自動送字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_press_full_auto_send), label_gtab_gtab_press_full_auto_send,  FALSE, FALSE, 0);
   check_button_gtab_press_full_auto_send = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_press_full_auto_send), check_button_gtab_press_full_auto_send,  FALSE, FALSE, 0);
@@ -230,7 +234,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_disp_partial_match = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_disp_partial_match, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_disp_partial_match = gtk_label_new("預選列中顯示部份符合的字");
+  GtkWidget *label_gtab_gtab_disp_partial_match = gtk_label_new(_("預選列中顯示部份符合的字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_partial_match), label_gtab_gtab_disp_partial_match,  FALSE, FALSE, 0);
   check_button_gtab_disp_partial_match = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_partial_match), check_button_gtab_disp_partial_match,  FALSE, FALSE, 0);
@@ -241,7 +245,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_simple_win = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_simple_win, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_simple_win = gtk_label_new("較小視窗");
+  GtkWidget *label_gtab_gtab_simple_win = gtk_label_new(_("較小視窗"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_simple_win), label_gtab_gtab_simple_win,  FALSE, FALSE, 0);
   check_button_gtab_simple_win = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_simple_win), check_button_gtab_simple_win,  FALSE, FALSE, 0);
@@ -252,7 +256,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_disp_key_codes = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_disp_key_codes, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_disp_key_codes = gtk_label_new("顯示拆字");
+  GtkWidget *label_gtab_gtab_disp_key_codes = gtk_label_new(_("顯示拆字"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_key_codes), label_gtab_gtab_disp_key_codes,  FALSE, FALSE, 0);
   check_button_gtab_disp_key_codes = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_key_codes), check_button_gtab_disp_key_codes,  FALSE, FALSE, 0);
@@ -263,7 +267,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_disp_im_name = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_disp_im_name, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_disp_im_name = gtk_label_new("顯示輸入法名稱");
+  GtkWidget *label_gtab_gtab_disp_im_name = gtk_label_new(_("顯示輸入法名稱"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_im_name), label_gtab_gtab_disp_im_name,  FALSE, FALSE, 0);
   check_button_gtab_disp_im_name = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_disp_im_name), check_button_gtab_disp_im_name,  FALSE, FALSE, 0);
@@ -274,7 +278,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_invalid_key_in = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_invalid_key_in, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_invalid_key_in = gtk_label_new("錯誤鍵進入(傳統)");
+  GtkWidget *label_gtab_gtab_invalid_key_in = gtk_label_new(_("允許錯誤鍵進入(傳統)"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_invalid_key_in), label_gtab_gtab_invalid_key_in,  FALSE, FALSE, 0);
   check_button_gtab_invalid_key_in = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_invalid_key_in), check_button_gtab_invalid_key_in,  FALSE, FALSE, 0);
@@ -285,7 +289,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_shift_phrase_key = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_shift_phrase_key, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_gtab_shift_phrase_key = gtk_label_new("Shift 用來輸入片語(Alt-Shift)");
+  GtkWidget *label_gtab_gtab_shift_phrase_key = gtk_label_new(_("Shift 用來輸入片語(Alt-Shift)"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_shift_phrase_key), label_gtab_gtab_shift_phrase_key,  FALSE, FALSE, 0);
   check_button_gtab_shift_phrase_key = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_shift_phrase_key), check_button_gtab_shift_phrase_key,  FALSE, FALSE, 0);
@@ -296,7 +300,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_hide_row2 = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_hide_row2, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_hide_row2 = gtk_label_new("隱藏第二列(輸入鍵…)");
+  GtkWidget *label_gtab_hide_row2 = gtk_label_new(_("隱藏第二列(輸入鍵…)"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_hide_row2), label_gtab_hide_row2,  FALSE, FALSE, 0);
   check_button_gtab_hide_row2 = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_hide_row2), check_button_gtab_hide_row2,  FALSE, FALSE, 0);
@@ -307,7 +311,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_in_row1 = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_in_row1, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_in_row1 = gtk_label_new("輸入鍵顯示移至第一列");
+  GtkWidget *label_gtab_in_row1 = gtk_label_new(_("輸入鍵顯示移至第一列"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_in_row1), label_gtab_in_row1,  FALSE, FALSE, 0);
   check_button_gtab_in_row1 = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_in_row1), check_button_gtab_in_row1,  FALSE, FALSE, 0);
@@ -318,17 +322,25 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_capslock_in_eng = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_capslock_in_eng, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_capslock_in_eng = gtk_label_new("CapsLock 打開輸入英數");
+  GtkWidget *label_gtab_capslock_in_eng = gtk_label_new(_("CapsLock 打開輸入英數"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_capslock_in_eng), label_gtab_capslock_in_eng,  FALSE, FALSE, 0);
   check_button_gtab_capslock_in_eng = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_capslock_in_eng), check_button_gtab_capslock_in_eng,  FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gtab_capslock_in_eng),
      gtab_capslock_in_eng);
 
+  GtkWidget *hbox_gcin_capslock_lower = gtk_hbox_new (FALSE, 10);
+  gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gcin_capslock_lower, FALSE, FALSE, 0);
+  GtkWidget *label_gcin_capslock_lower = gtk_label_new(_("\t用小寫字母"));
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_capslock_lower), label_gcin_capslock_lower,  FALSE, FALSE, 0);
+  check_button_gcin_capslock_lower = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_capslock_lower), check_button_gcin_capslock_lower,  FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_capslock_lower),
+     gcin_capslock_lower);
 
   GtkWidget *hbox_gtab_vertical_select = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_vertical_select, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_vertical_select = gtk_label_new("垂直選擇");
+  GtkWidget *label_gtab_vertical_select = gtk_label_new(_("垂直選擇"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_vertical_select), label_gtab_vertical_select,  FALSE, FALSE, 0);
   check_button_gtab_vertical_select = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_vertical_select), check_button_gtab_vertical_select,  FALSE, FALSE, 0);
@@ -338,7 +350,7 @@ void create_gtab_conf_window()
 
   GtkWidget *hbox_gtab_unique_auto_send = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_gtab), hbox_gtab_unique_auto_send, FALSE, FALSE, 0);
-  GtkWidget *label_gtab_unique_auto_send = gtk_label_new("唯一選擇時自動送出");
+  GtkWidget *label_gtab_unique_auto_send = gtk_label_new(_("唯一選擇時自動送出"));
   gtk_box_pack_start (GTK_BOX (hbox_gtab_unique_auto_send), label_gtab_unique_auto_send,  FALSE, FALSE, 0);
   check_button_gtab_unique_auto_send = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_gtab_unique_auto_send), check_button_gtab_unique_auto_send,  FALSE, FALSE, 0);
@@ -346,7 +358,7 @@ void create_gtab_conf_window()
      gtab_unique_auto_send);
 
 
-  GtkWidget *button_edit_append = gtk_button_new_with_label("編輯內定輸入法的使用者外加字詞");
+  GtkWidget *button_edit_append = gtk_button_new_with_label(_("編輯內定輸入法的使用者外加字詞"));
   gtk_box_pack_start (GTK_BOX (vbox_gtab), button_edit_append, FALSE, FALSE, 0);
 
   g_signal_connect_swapped (G_OBJECT (button_edit_append), "clicked",
