@@ -30,6 +30,7 @@ static GtkWidget *check_button_tsin_phrase_pre_select,
                  *check_button_tsin_tone_char_input,
                  *check_button_tsin_tab_phrase_end,
                  *check_button_tsin_tail_select_key,
+                 *check_button_gcin_capslock_lower,
                  *spinner_tsin_buffer_size;
 
 static GtkWidget *opt_kbm_opts;
@@ -108,6 +109,9 @@ static gboolean cb_ok( GtkWidget *widget,
   save_gcin_conf_int(TSIN_TAIL_SELECT_KEY,
        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_tsin_tail_select_key)));
 
+  save_gcin_conf_int(GCIN_CAPSLOCK_LOWER,
+       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button_gcin_capslock_lower)));
+
   tsin_buffer_size = (int) gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinner_tsin_buffer_size));
   save_gcin_conf_int(TSIN_BUFFER_SIZE, tsin_buffer_size);
 
@@ -202,7 +206,7 @@ static void cb_save_tsin_phrase_line_color(GtkWidget *widget, gpointer user_data
 static gboolean cb_tsin_phrase_line_color( GtkWidget *widget,
                                    gpointer   data )
 {
-   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)gtk_color_selection_dialog_new ("詞音標示詞的底線顏色");
+   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)gtk_color_selection_dialog_new (_("詞音標示詞的底線顏色"));
 
    gtk_color_selection_set_current_color(
            GTK_COLOR_SELECTION(color_selector->colorsel),
@@ -241,7 +245,7 @@ static void cb_save_tsin_cursor_color(GtkWidget *widget, gpointer user_data)
 static gboolean cb_tsin_cursor_color( GtkWidget *widget,
                                    gpointer   data )
 {
-   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)gtk_color_selection_dialog_new ("詞音標示詞的底線顏色");
+   GtkColorSelectionDialog *color_selector = (GtkColorSelectionDialog *)gtk_color_selection_dialog_new (_("詞音游標的顏色"));
 
    gtk_color_selection_set_current_color(
            GTK_COLOR_SELECTION(color_selector->colorsel),
@@ -311,20 +315,20 @@ void create_kbm_window()
                     G_CALLBACK (close_kbm_window),
                     NULL);
 
-  gtk_window_set_title (GTK_WINDOW (gcin_kbm_window), "gcin 注音/詞音設定");
+  gtk_window_set_title (GTK_WINDOW (gcin_kbm_window), _("gcin 注音/詞音設定"));
   gtk_container_set_border_width (GTK_CONTAINER (gcin_kbm_window), 1);
 
   GtkWidget *vbox_top = gtk_vbox_new (FALSE, 3);
   gtk_container_add (GTK_CONTAINER (gcin_kbm_window), vbox_top);
 
-  GtkWidget *frame_kbm = gtk_frame_new("鍵盤排列方式");
+  GtkWidget *frame_kbm = gtk_frame_new(_("鍵盤排列方式"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_kbm, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_kbm), 1);
 
   gtk_container_add (GTK_CONTAINER (frame_kbm), create_kbm_opts());
 
 
-  GtkWidget *frame_tsin_sw = gtk_frame_new("詞音輸入[中/英]切換");
+  GtkWidget *frame_tsin_sw = gtk_frame_new(_("詞音輸入[中/英]切換"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_tsin_sw, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_tsin_sw), 1);
 
@@ -351,7 +355,7 @@ void create_kbm_window()
   }
 
 
-  GtkWidget *frame_tsin_space_opt = gtk_frame_new("詞音輸入空白鍵選項");
+  GtkWidget *frame_tsin_space_opt = gtk_frame_new(_("詞音輸入空白鍵選項"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_tsin_space_opt, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_tsin_space_opt), 1);
 
@@ -379,7 +383,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_tsin_phrase_pre_select = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_tsin_phrase_pre_select , TRUE, TRUE, 1);
-  GtkWidget *label_tsin_phrase_pre_select = gtk_label_new("詞音輸入預選詞視窗");
+  GtkWidget *label_tsin_phrase_pre_select = gtk_label_new(_("詞音輸入預選詞視窗"));
   gtk_box_pack_start (GTK_BOX (hbox_tsin_phrase_pre_select), label_tsin_phrase_pre_select , TRUE, TRUE, 0);
   check_button_tsin_phrase_pre_select = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_tsin_phrase_pre_select), check_button_tsin_phrase_pre_select, FALSE, FALSE, 0);
@@ -389,7 +393,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_phonetic_char_dynamic_sequence = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_phonetic_char_dynamic_sequence , TRUE, TRUE, 1);
-  GtkWidget *label_phonetic_char_dynamic_sequence = gtk_label_new("依使用頻率調整字的順序");
+  GtkWidget *label_phonetic_char_dynamic_sequence = gtk_label_new(_("依使用頻率調整字的順序"));
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_char_dynamic_sequence), label_phonetic_char_dynamic_sequence , TRUE, TRUE, 0);
   check_button_phonetic_char_dynamic_sequence = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_char_dynamic_sequence), check_button_phonetic_char_dynamic_sequence, FALSE, FALSE, 0);
@@ -399,7 +403,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_pho_simple_win = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_pho_simple_win , TRUE, TRUE, 1);
-  GtkWidget *label_pho_simple_win = gtk_label_new("詞音/注音精簡視窗");
+  GtkWidget *label_pho_simple_win = gtk_label_new(_("詞音/注音精簡視窗"));
   gtk_box_pack_start (GTK_BOX (hbox_pho_simple_win), label_pho_simple_win , TRUE, TRUE, 0);
   check_button_pho_simple_win = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_pho_simple_win), check_button_pho_simple_win, FALSE, FALSE, 0);
@@ -409,7 +413,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_pho_hide_row2 = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_pho_hide_row2 , TRUE, TRUE, 1);
-  GtkWidget *label_pho_hide_row2 = gtk_label_new("注音隱藏第二列(按鍵顯示)");
+  GtkWidget *label_pho_hide_row2 = gtk_label_new(_("注音隱藏第二列(按鍵顯示)"));
   gtk_box_pack_start (GTK_BOX (hbox_pho_hide_row2), label_pho_hide_row2 , TRUE, TRUE, 0);
   check_button_pho_hide_row2 = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_pho_hide_row2), check_button_pho_hide_row2, FALSE, FALSE, 0);
@@ -419,7 +423,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_pho_in_row1 = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_pho_in_row1 , TRUE, TRUE, 1);
-  GtkWidget *label_pho_in_row1 = gtk_label_new("注音輸入顯示移至第一列");
+  GtkWidget *label_pho_in_row1 = gtk_label_new(_("注音輸入顯示移至第一列"));
   gtk_box_pack_start (GTK_BOX (hbox_pho_in_row1), label_pho_in_row1 , TRUE, TRUE, 0);
   check_button_pho_in_row1 = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_pho_in_row1), check_button_pho_in_row1, FALSE, FALSE, 0);
@@ -429,7 +433,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_phonetic_huge_tab = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_phonetic_huge_tab , TRUE, TRUE, 1);
-  GtkWidget *label_phonetic_huge_tab = gtk_label_new("使用巨大 UTF-8 字集");
+  GtkWidget *label_phonetic_huge_tab = gtk_label_new(_("使用巨大 UTF-8 字集"));
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_huge_tab), label_phonetic_huge_tab , TRUE, TRUE, 0);
   check_button_phonetic_huge_tab = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_huge_tab), check_button_phonetic_huge_tab, FALSE, FALSE, 0);
@@ -439,7 +443,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_tsin_tone_char_input = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_tsin_tone_char_input , TRUE, TRUE, 1);
-  GtkWidget *label_tsin_tone_char_input = gtk_label_new("詞音輸入注音聲調符號");
+  GtkWidget *label_tsin_tone_char_input = gtk_label_new(_("詞音輸入注音聲調符號"));
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tone_char_input), label_tsin_tone_char_input , TRUE, TRUE, 0);
   check_button_tsin_tone_char_input = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tone_char_input), check_button_tsin_tone_char_input, FALSE, FALSE, 0);
@@ -449,7 +453,7 @@ void create_kbm_window()
 
   GtkWidget *hbox_tsin_tab_phrase_end = gtk_hbox_new(FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_tsin_tab_phrase_end , TRUE, TRUE, 1);
-  GtkWidget *label_tsin_tab_phrase_end = gtk_label_new("詞音/Escape Tab 斷詞");
+  GtkWidget *label_tsin_tab_phrase_end = gtk_label_new(_("詞音/Escape Tab 斷詞"));
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tab_phrase_end), label_tsin_tab_phrase_end , TRUE, TRUE, 0);
   check_button_tsin_tab_phrase_end = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tab_phrase_end), check_button_tsin_tab_phrase_end, FALSE, FALSE, 0);
@@ -458,14 +462,25 @@ void create_kbm_window()
 
   GtkWidget *hbox_tsin_tail_select_key = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_tsin_tail_select_key , TRUE, TRUE, 1);
-  GtkWidget *label_tsin_tail_select_key = gtk_label_new("同音字詞選擇按鍵在後");
+  GtkWidget *label_tsin_tail_select_key = gtk_label_new(_("同音字詞選擇按鍵在後"));
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tail_select_key), label_tsin_tail_select_key , TRUE, TRUE, 0);
   check_button_tsin_tail_select_key = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_tsin_tail_select_key), check_button_tsin_tail_select_key, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(
      GTK_TOGGLE_BUTTON(check_button_tsin_tail_select_key), tsin_tail_select_key);
 
-  GtkWidget *frame_tsin_buffer_size = gtk_frame_new("詞音編輯緩衝區大小");
+
+  GtkWidget *hbox_gcin_capslock_lower = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_capslock_lower , TRUE, TRUE, 1);
+  GtkWidget *label_gcin_capslock_lower = gtk_label_new(_("Capslock英數用小寫"));
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_capslock_lower), label_gcin_capslock_lower , TRUE, TRUE, 0);
+  check_button_gcin_capslock_lower = gtk_check_button_new ();
+  gtk_box_pack_start (GTK_BOX (hbox_gcin_capslock_lower), check_button_gcin_capslock_lower, FALSE, FALSE, 0);
+  gtk_toggle_button_set_active(
+     GTK_TOGGLE_BUTTON(check_button_gcin_capslock_lower), gcin_capslock_lower);
+
+
+  GtkWidget *frame_tsin_buffer_size = gtk_frame_new(_("詞音編輯緩衝區大小"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_tsin_buffer_size, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_tsin_buffer_size), 1);
   GtkAdjustment *adj_gtab_in =
@@ -474,7 +489,7 @@ void create_kbm_window()
   gtk_container_add (GTK_CONTAINER (frame_tsin_buffer_size), spinner_tsin_buffer_size);
 
 
-  GtkWidget *frame_tsin_phrase_line_color = gtk_frame_new("詞音標示詞的底線顏色");
+  GtkWidget *frame_tsin_phrase_line_color = gtk_frame_new(_("詞音標示詞的底線顏色"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_tsin_phrase_line_color, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_tsin_phrase_line_color), 1);
   GtkWidget *button_tsin_phrase_line_color = gtk_button_new();
@@ -487,7 +502,7 @@ void create_kbm_window()
   gtk_widget_set_size_request(da, 16, 2);
   gtk_container_add (GTK_CONTAINER (frame_tsin_phrase_line_color), button_tsin_phrase_line_color);
 
-  GtkWidget *frame_tsin_cursor_color = gtk_frame_new("詞音游標的顏色");
+  GtkWidget *frame_tsin_cursor_color = gtk_frame_new(_("詞音游標的顏色"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_tsin_cursor_color, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_tsin_cursor_color), 1);
   GtkWidget *button_tsin_cursor_color = gtk_button_new();
