@@ -1,5 +1,7 @@
 #include "gcin.h"
 #include "gtab.h"
+#include "config.h"
+#include <libintl.h>
 
 
 static GtkWidget *check_button_root_style_use,
@@ -93,7 +95,7 @@ static void cb_ts_export()
 {
    /* Create the selector */
 
-   GtkWidget *file_selector = gtk_file_selection_new ("請輸入要匯出的檔案名稱");
+   GtkWidget *file_selector = gtk_file_selection_new (_("請輸入要匯出的檔案名稱"));
 
    g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
                      "clicked",
@@ -133,7 +135,7 @@ static void cb_ts_import()
 {
    /* Create the selector */
 
-   GtkWidget *file_selector = gtk_file_selection_new ("請輸入要匯入的檔案名稱");
+   GtkWidget *file_selector = gtk_file_selection_new (_("請輸入要匯入的檔案名稱"));
 
    g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
                      "clicked",
@@ -361,7 +363,7 @@ void create_appearance_conf_window()
                     G_CALLBACK (close_appearance_conf_window),
                     NULL);
 
-  gtk_window_set_title (GTK_WINDOW (gcin_appearance_conf_window), "輸入視窗外觀設定");
+  gtk_window_set_title (GTK_WINDOW (gcin_appearance_conf_window), _("輸入視窗外觀設定"));
   gtk_container_set_border_width (GTK_CONTAINER (gcin_appearance_conf_window), 3);
 
   GtkWidget *vbox_top = gtk_vbox_new (FALSE, 10);
@@ -369,7 +371,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_font_size = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_font_size, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_font_size = gtk_label_new("字型大小");
+  GtkWidget *label_gcin_font_size = gtk_label_new(_("字型大小"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_font_size), label_gcin_font_size, FALSE, FALSE, 0);
   GtkAdjustment *adj_gcin_font_size =
    (GtkAdjustment *) gtk_adjustment_new (gcin_font_size, 8.0, 32.0, 1.0, 1.0, 0.0);
@@ -379,7 +381,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_font_size_symbol = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_font_size_symbol, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_font_size_symbol = gtk_label_new("符號選擇視窗字型大小");
+  GtkWidget *label_gcin_font_size_symbol = gtk_label_new(_("符號選擇視窗字型大小"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_font_size_symbol), label_gcin_font_size_symbol, FALSE, FALSE, 0);
   GtkAdjustment *adj_gcin_font_size_symbol =
    (GtkAdjustment *) gtk_adjustment_new (gcin_font_size_symbol, 8.0, 32.0, 1.0, 1.0, 0.0);
@@ -389,7 +391,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_font_size_tsin_presel = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_font_size_tsin_presel, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_font_size_tsin_presel = gtk_label_new("詞音預選詞視窗字型大小");
+  GtkWidget *label_gcin_font_size_tsin_presel = gtk_label_new(_("詞音預選詞視窗字型大小"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_font_size_tsin_presel), label_gcin_font_size_tsin_presel, FALSE, FALSE, 0);
   GtkAdjustment *adj_gcin_font_size_tsin_presel =
    (GtkAdjustment *) gtk_adjustment_new (gcin_font_size_tsin_presel, 8.0, 32.0, 1.0, 1.0, 0.0);
@@ -399,7 +401,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_font_size_tsin_pho_in = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_font_size_tsin_pho_in, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_font_size_tsin_pho_in = gtk_label_new("詞音注音輸入區字型大小");
+  GtkWidget *label_gcin_font_size_tsin_pho_in = gtk_label_new(_("詞音注音輸入區字型大小"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_font_size_tsin_pho_in), label_gcin_font_size_tsin_pho_in, FALSE, FALSE, 0);
   GtkAdjustment *adj_gcin_font_size_tsin_pho_in =
    (GtkAdjustment *) gtk_adjustment_new (gcin_font_size_tsin_pho_in, 8.0, 32.0, 1.0, 1.0, 0.0);
@@ -409,7 +411,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_font_size_pho_near = gtk_hbox_new (FALSE, 14);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_font_size_pho_near, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_font_size_pho_near = gtk_label_new("詞音近似音顯示字型大小");
+  GtkWidget *label_gcin_font_size_pho_near = gtk_label_new(_("詞音近似音顯示字型大小"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_font_size_pho_near), label_gcin_font_size_pho_near, FALSE, FALSE, 0);
   GtkAdjustment *adj_gcin_font_size_pho_near =
    (GtkAdjustment *) gtk_adjustment_new (gcin_font_size_pho_near, 8.0, 32.0, 1.0, 1.0, 0.0);
@@ -419,7 +421,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_font_size_gtab_in = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vbox_top), hbox_gcin_font_size_gtab_in, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_font_size_gtab_in = gtk_label_new("gtab(倉頡…)輸入區字型大小");
+  GtkWidget *label_gcin_font_size_gtab_in = gtk_label_new(_("gtab(倉頡…)輸入區字型大小"));
   gtk_box_pack_start (GTK_BOX (hbox_gcin_font_size_gtab_in), label_gcin_font_size_gtab_in, FALSE, FALSE, 0);
   GtkAdjustment *adj_gcin_font_size_gtab_in =
    (GtkAdjustment *) gtk_adjustment_new (gcin_font_size_gtab_in, 8.0, 32.0, 1.0, 1.0, 0.0);
@@ -435,14 +437,14 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_pop_up_win = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX(vbox_top), hbox_gcin_pop_up_win, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_pop_up_win = gtk_label_new("彈出式輸入視窗");
+  GtkWidget *label_gcin_pop_up_win = gtk_label_new(_("彈出式輸入視窗"));
   gtk_box_pack_start (GTK_BOX(hbox_gcin_pop_up_win), label_gcin_pop_up_win, FALSE, FALSE, 0);
   check_button_gcin_pop_up_win = gtk_check_button_new ();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_pop_up_win),
        gcin_pop_up_win);
   gtk_box_pack_start (GTK_BOX(hbox_gcin_pop_up_win), check_button_gcin_pop_up_win, FALSE, FALSE, 0);
 
-  GtkWidget *frame_root_style = gtk_frame_new("固定 gcin 視窗位置");
+  GtkWidget *frame_root_style = gtk_frame_new(_("固定 gcin 視窗位置"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_root_style, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_root_style), 3);
   GtkWidget *vbox_root_style = gtk_vbox_new (FALSE, 10);
@@ -450,7 +452,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_root_style_use = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX(vbox_root_style), hbox_root_style_use, FALSE, FALSE, 0);
-  GtkWidget *label_root_style_use = gtk_label_new("使用");
+  GtkWidget *label_root_style_use = gtk_label_new(_("使用"));
   gtk_box_pack_start (GTK_BOX(hbox_root_style_use), label_root_style_use, FALSE, FALSE, 0);
   check_button_root_style_use = gtk_check_button_new ();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_root_style_use),
@@ -474,7 +476,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_gcin_inner_frame = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX(vbox_top), hbox_gcin_inner_frame, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_inner_frame = gtk_label_new("顯示內框");
+  GtkWidget *label_gcin_inner_frame = gtk_label_new(_("顯示內框"));
   gtk_box_pack_start (GTK_BOX(hbox_gcin_inner_frame), label_gcin_inner_frame, FALSE, FALSE, 0);
   check_button_gcin_inner_frame = gtk_check_button_new ();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_inner_frame),
@@ -484,7 +486,7 @@ void create_appearance_conf_window()
 #if TRAY_ENABLED
   GtkWidget *hbox_gcin_status_tray = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX(vbox_top), hbox_gcin_status_tray, FALSE, FALSE, 0);
-  GtkWidget *label_gcin_status_tray = gtk_label_new("面板狀態(tray)");
+  GtkWidget *label_gcin_status_tray = gtk_label_new(_("面板狀態(tray)"));
   gtk_box_pack_start (GTK_BOX(hbox_gcin_status_tray), label_gcin_status_tray, FALSE, FALSE, 0);
   check_button_gcin_status_tray = gtk_check_button_new ();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_status_tray),
@@ -492,7 +494,7 @@ void create_appearance_conf_window()
   gtk_box_pack_start (GTK_BOX(hbox_gcin_status_tray), check_button_gcin_status_tray, FALSE, FALSE, 0);
 #endif
 
-  GtkWidget *frame_win_color = gtk_frame_new("顏色選擇");
+  GtkWidget *frame_win_color = gtk_frame_new(_("顏色選擇"));
   gtk_box_pack_start (GTK_BOX (vbox_top), frame_win_color, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame_win_color), 3);
   GtkWidget *vbox_win_color = gtk_vbox_new (FALSE, 10);
@@ -500,7 +502,7 @@ void create_appearance_conf_window()
 
   GtkWidget *hbox_win_color_use = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX(vbox_win_color), hbox_win_color_use, FALSE, FALSE, 0);
-  GtkWidget *label_win_color_use = gtk_label_new("使用");
+  GtkWidget *label_win_color_use = gtk_label_new(_("使用"));
   gtk_box_pack_start (GTK_BOX(hbox_win_color_use), label_win_color_use, FALSE, FALSE, 0);
   check_button_gcin_win_color_use = gtk_check_button_new ();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button_gcin_win_color_use),
@@ -508,11 +510,11 @@ void create_appearance_conf_window()
   gtk_box_pack_start (GTK_BOX(hbox_win_color_use), check_button_gcin_win_color_use, FALSE, FALSE, 0);
   event_box_win_color_test = gtk_event_box_new();
   gtk_box_pack_start (GTK_BOX(vbox_win_color), event_box_win_color_test, FALSE, FALSE, 0);
-  label_win_color_test = gtk_label_new("測試目前狀態");
+  label_win_color_test = gtk_label_new(_("測試目前狀態"));
   gtk_container_add (GTK_BOX(event_box_win_color_test), label_win_color_test);
   GtkWidget *hbox_win_color_fbg = gtk_hbox_new (FALSE, 10);
   gtk_box_pack_start (GTK_BOX(vbox_win_color), hbox_win_color_fbg, FALSE, FALSE, 0);
-  GtkWidget *button_fg = gtk_button_new_with_label("前景顏色");
+  GtkWidget *button_fg = gtk_button_new_with_label(_("前景顏色"));
   gtk_box_pack_start (GTK_BOX(hbox_win_color_fbg), button_fg, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_fg), "clicked",
                     G_CALLBACK (cb_gcin_win_color_fg), &colorsel[0]);
@@ -522,7 +524,7 @@ void create_appearance_conf_window()
   gdk_color_parse(gcin_win_color_bg, &gcin_win_gcolor_bg);
   gtk_widget_modify_bg(event_box_win_color_test, GTK_STATE_NORMAL, &gcin_win_gcolor_bg);
 
-  GtkWidget *button_bg = gtk_button_new_with_label("背景顏色");
+  GtkWidget *button_bg = gtk_button_new_with_label(_("背景顏色"));
   gtk_box_pack_start (GTK_BOX(hbox_win_color_fbg), button_bg, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_bg), "clicked",
                     G_CALLBACK (cb_gcin_win_color_fg), &colorsel[1]);
@@ -587,6 +589,14 @@ static void cb_juying_learn()
 }
 
 
+int gcin_pid;
+
+static void cb_gcin_exit()
+{
+  kill(gcin_pid, 9);
+}
+
+
 void create_gtablist_window();
 static void cb_default_input_method()
 {
@@ -609,56 +619,56 @@ static void create_main_win()
   GtkWidget *vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (main_window), vbox);
 
-  GtkWidget *button_kbm = gtk_button_new_with_label("gcin 注音/詞音設定");
+  GtkWidget *button_kbm = gtk_button_new_with_label(_("gcin 注音/詞音設定"));
   gtk_box_pack_start (GTK_BOX (vbox), button_kbm, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_kbm), "clicked",
                     G_CALLBACK (cb_kbm), NULL);
 
-  GtkWidget *button_appearance_conf = gtk_button_new_with_label("外觀設定");
+  GtkWidget *button_appearance_conf = gtk_button_new_with_label(_("外觀設定"));
   gtk_box_pack_start (GTK_BOX (vbox), button_appearance_conf, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_appearance_conf), "clicked",
                     G_CALLBACK (cb_appearance_conf), NULL);
 
-  GtkWidget *button_gtab_conf = gtk_button_new_with_label("倉頡/行列/嘸蝦米/大易設定");
+  GtkWidget *button_gtab_conf = gtk_button_new_with_label(_("倉頡/行列/嘸蝦米/大易設定"));
   gtk_box_pack_start (GTK_BOX (vbox), button_gtab_conf, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_gtab_conf), "clicked",
                     G_CALLBACK (cb_gtab_conf), NULL);
 
 
-  GtkWidget *button_default_input_method = gtk_button_new_with_label("內定輸入法 & 開啟/關閉");
+  GtkWidget *button_default_input_method = gtk_button_new_with_label(_("內定輸入法 & 開啟/關閉"));
   gtk_box_pack_start (GTK_BOX (vbox), button_default_input_method, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_default_input_method), "clicked",
                     G_CALLBACK (cb_default_input_method), NULL);
 
 
 
-  GtkWidget *button_alt_shift = gtk_button_new_with_label("alt-shift 片語編輯");
+  GtkWidget *button_alt_shift = gtk_button_new_with_label(_("alt-shift 片語編輯"));
   gtk_box_pack_start (GTK_BOX (vbox), button_alt_shift, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_alt_shift), "clicked",
                     G_CALLBACK (cb_alt_shift), NULL);
 
-  GtkWidget *button_symbol_table = gtk_button_new_with_label("符號表編輯");
+  GtkWidget *button_symbol_table = gtk_button_new_with_label(_("符號表編輯"));
   gtk_box_pack_start (GTK_BOX (vbox), button_symbol_table, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_symbol_table), "clicked",
                     G_CALLBACK (cb_symbol_table), NULL);
 
-  GtkWidget *button_gb_output_toggle = gtk_button_new_with_label("簡體字輸出切換");
+  GtkWidget *button_gb_output_toggle = gtk_button_new_with_label(_("簡體字輸出切換"));
   gtk_box_pack_start (GTK_BOX (vbox), button_gb_output_toggle, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_gb_output_toggle), "clicked",
                     G_CALLBACK (cb_gb_output_toggle), NULL);
 
-  GtkWidget *button_gb_translate_toggle = gtk_button_new_with_label("剪貼區 簡體字->正體字");
+  GtkWidget *button_gb_translate_toggle = gtk_button_new_with_label(_("剪貼區 簡體字->正體字"));
   gtk_box_pack_start (GTK_BOX (vbox), button_gb_translate_toggle, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_gb_translate_toggle), "clicked",
                     G_CALLBACK (cb_gb_translate_toggle), NULL);
 
-  GtkWidget *button_juying_learn_toggle = gtk_button_new_with_label("剪貼區 注音查詢");
+  GtkWidget *button_juying_learn_toggle = gtk_button_new_with_label(_("剪貼區 注音查詢"));
   gtk_box_pack_start (GTK_BOX (vbox), button_juying_learn_toggle, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_juying_learn_toggle), "clicked",
                     G_CALLBACK (cb_juying_learn), NULL);
 
 #if GTK_MAJOR_VERSION >=2 && GTK_MINOR_VERSION >= 4
-  GtkWidget *expander_ts = gtk_expander_new ("詞庫選項");
+  GtkWidget *expander_ts = gtk_expander_new (_("詞庫選項"));
   gtk_box_pack_start (GTK_BOX (vbox), expander_ts, FALSE, FALSE, 0);
   GtkWidget *vbox_ts = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (expander_ts), vbox_ts);
@@ -667,32 +677,32 @@ static void create_main_win()
   gtk_box_pack_start (GTK_BOX (vbox), vbox_ts, FALSE, FALSE, 0);
 #endif
 
-  GtkWidget *button_ts_export = gtk_button_new_with_label("詞庫匯出");
+  GtkWidget *button_ts_export = gtk_button_new_with_label(_("詞庫匯出"));
   gtk_box_pack_start (GTK_BOX (vbox_ts), button_ts_export, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (button_ts_export), "clicked",
                     G_CALLBACK (cb_ts_export), NULL);
 
-  GtkWidget *button_ts_import = gtk_button_new_with_label("詞庫匯入");
+  GtkWidget *button_ts_import = gtk_button_new_with_label(_("詞庫匯入"));
   gtk_box_pack_start (GTK_BOX (vbox_ts), button_ts_import, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (button_ts_import), "clicked",
                     G_CALLBACK (cb_ts_import), NULL);
 
-  GtkWidget *button_ts_edit = gtk_button_new_with_label("詞庫編輯");
+  GtkWidget *button_ts_edit = gtk_button_new_with_label(_("詞庫編輯"));
   gtk_box_pack_start (GTK_BOX (vbox_ts), button_ts_edit, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_ts_edit), "clicked",
                     G_CALLBACK (cb_ts_edit), NULL);
 
-  GtkWidget *button_tslearn = gtk_button_new_with_label("讓詞音從文章學習詞");
+  GtkWidget *button_tslearn = gtk_button_new_with_label(_("讓詞音從文章學習詞"));
   gtk_box_pack_start (GTK_BOX (vbox_ts), button_tslearn, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_tslearn), "clicked",
                     G_CALLBACK (cb_tslearn), NULL);
 
-  GtkWidget *button_ts_import_sys = gtk_button_new_with_label("匯入系統的詞庫");
+  GtkWidget *button_ts_import_sys = gtk_button_new_with_label(_("匯入系統的詞庫"));
   gtk_box_pack_start (GTK_BOX (vbox_ts), button_ts_import_sys, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_ts_import_sys), "clicked",
                     G_CALLBACK (cb_ts_import_sys), NULL);
 
-  GtkWidget *button_about = gtk_button_new_with_label("關於 gcin");
+  GtkWidget *button_about = gtk_button_new_with_label(_("關於 gcin"));
   gtk_box_pack_start (GTK_BOX (vbox), button_about, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_about), "clicked",
                     G_CALLBACK (create_about_window),  NULL);
@@ -703,6 +713,16 @@ static void create_main_win()
   g_signal_connect (G_OBJECT (button_help), "clicked",
                     G_CALLBACK (cb_help), NULL);
 
+  char *pid = getenv("GCIN_PID");
+
+  if (pid && (gcin_pid = atoi(pid))) {
+    GtkWidget *button_gcin_exit = gtk_button_new_with_label (_("結束 gcin"));
+    gtk_box_pack_start (GTK_BOX (vbox), button_gcin_exit, TRUE, TRUE, 0);
+    g_signal_connect (G_OBJECT (button_gcin_exit), "clicked",
+                      G_CALLBACK (cb_gcin_exit), NULL);
+  }
+
+
   GtkWidget *button_quit = gtk_button_new_from_stock (GTK_STOCK_QUIT);
   gtk_box_pack_start (GTK_BOX (vbox), button_quit, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button_quit), "clicked",
@@ -712,14 +732,26 @@ static void create_main_win()
 }
 
 
-void init_TableDir();
+void init_TableDir(), exec_setup_scripts();
 
 int main(int argc, char **argv)
 {
+//  char *messages=getenv("LC_MESSAGES");
+#if 0
+  char *ctype=getenv("LC_CTYPE");
+  if (!(ctype && strstr(ctype, "zh_CN")))
+    putenv("LANGUAGE=zh_TW.UTF-8");
+#endif
+  exec_setup_scripts();
+
   init_TableDir();
 
   load_setttings();
 
+  gtk_set_locale();
+  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
+
   gtk_init(&argc, &argv);
 
   create_main_win();
